@@ -6,6 +6,7 @@ module Hledger.Web (
                      module Hledger.Web.Foundation,
                      module Hledger.Web.Application,
                      module Hledger.Web.Handlers,
+                     module Hledger.Web.Import,
                      module Hledger.Web.Options,
                      module Hledger.Web.Settings,
                      module Hledger.Web.Settings.StaticFiles,
@@ -17,6 +18,7 @@ import Test.HUnit
 import Hledger.Web.Foundation
 import Hledger.Web.Application
 import Hledger.Web.Handlers
+import Hledger.Web.Import
 import Hledger.Web.Options
 import Hledger.Web.Settings
 import Hledger.Web.Settings.StaticFiles
