@@ -7,13 +7,15 @@ hledger-web's request handlers, and helpers.
 
 module Hledger.Web.Handlers where
 
+import Prelude
 import Control.Applicative ((<$>))
-import Data.Aeson
+-- import Data.Aeson
 import Data.ByteString (ByteString)
 import Data.Either (lefts,rights)
 import Data.List
 import Data.Maybe
 import Data.Text(Text,pack,unpack)
+import qualified Data.Text (null)
 import Data.Time.Calendar
 import Data.Time.Clock
 import Data.Time.Format
@@ -24,23 +26,25 @@ import Text.Blaze (preEscapedString, toHtml)
 import Text.Hamlet hiding (hamletFile)
 import Text.Printf
 import Yesod.Core
-import Yesod.Json
+-- import Yesod.Json
 
 import Hledger hiding (today)
-import Hledger.Cli
+import Hledger.Cli hiding (version)
 import Hledger.Web.Foundation
 import Hledger.Web.Options
 import Hledger.Web.Settings
 
 
-getFaviconR :: Handler ()
-getFaviconR = sendFile "image/x-icon" $ Hledger.Web.Settings.staticDir </> "favicon.ico"
+-- getFaviconR :: Handler ()
+-- getFaviconR = sendFile "image/x-icon" $ Hledger.Web.Settings.staticDir </> "favicon.ico"
 
-getRobotsR :: Handler RepPlain
-getRobotsR = return $ RepPlain $ toContent ("User-agent: *" :: ByteString)
+-- getRobotsR :: Handler RepPlain
+-- getRobotsR = return $ RepPlain $ toContent ("User-agent: *" :: ByteString)
 
 getRootR :: Handler RepHtml
-getRootR = redirect RedirectTemporary defaultroute where defaultroute = RegisterR
+getRootR = redirect defaultroute where defaultroute = RegisterR
+
+type AppRoute = Route App
 
 ----------------------------------------------------------------------
 -- main views:
@@ -164,6 +168,7 @@ getRegisterOnlyR = do
 
 ----------------------------------------------------------------------
 
+{-
 -- | A simple accounts view. This one is json-capable, returning the chart
 -- of accounts as json if the Accept header specifies json.
 getAccountsR :: Handler RepHtmlJson
@@ -182,6 +187,7 @@ getAccountsJsonR = do
   VD{..} <- getViewData
   let j' = filterJournalPostings2 m j
   jsonToRepJson $ jsonMap [("accounts", toJSON $ journalAccountNames j')]
+-}
 
 ----------------------------------------------------------------------
 -- view helpers
@@ -388,12 +394,15 @@ $forall p <- tpostings t
 
 -- | Generate javascript/html for a register balance line chart based on
 -- the provided "TransactionsReportItem"s.
-registerChartHtml items = [$hamlet|
+registerChartHtml items =
+ -- have to make sure plot is not called when our container (maincontent)
+ -- is hidden, eg with add form toggled
+ [$hamlet|
 <script type=text/javascript>
-  $(document).ready(function() {
+ if (document.getElementById('maincontent').style.display != 'none')
+  \$(document).ready(function() {
     /* render chart */
-    /* if ($('#register-chart')) */
-      $.plot($('#register-chart'),
+      \$.plot($('#register-chart'),
              [
               [
                $forall i <- items
@@ -436,20 +445,20 @@ mixedAmountAsHtml b = preEscapedString $ addclass $ intercalate "<br>" $ lines $
 -------------------------------------------------------------------------------
 -- post handlers
 
-postJournalR :: Handler RepPlain
+postJournalR :: Handler RepHtml
 postJournalR = handlePost
 
-postJournalEntriesR :: Handler RepPlain
+postJournalEntriesR :: Handler RepHtml
 postJournalEntriesR = handlePost
 
-postJournalEditR :: Handler RepPlain
+postJournalEditR :: Handler RepHtml
 postJournalEditR = handlePost
 
-postRegisterR :: Handler RepPlain
+postRegisterR :: Handler RepHtml
 postRegisterR = handlePost
 
 -- | Handle a post from any of the edit forms.
-handlePost :: Handler RepPlain
+handlePost :: Handler RepHtml
 handlePost = do
   action <- lookupPostParam  "action"
   case action of Just "add"    -> handleAdd
@@ -458,7 +467,7 @@ handlePost = do
                  _             -> invalidArgs [pack "invalid action"]
 
 -- | Handle a post from the transaction add form.
-handleAdd :: Handler RepPlain
+handleAdd :: Handler RepHtml
 handleAdd = do
   VD{..} <- getViewData
   -- get form input values. M means a Maybe value.
@@ -472,8 +481,9 @@ handleAdd = do
   -- supply defaults and parse date and amounts, or get errors.
   let dateE = maybe (Left "date required") (either (\e -> Left $ showDateParseError e) Right . fixSmartDateStrEither today . unpack) dateM
       descE = Right $ maybe "" unpack descM
-      acct1E = maybe (Left "to account required") (Right . unpack) acct1M
-      acct2E = maybe (Left "from account required") (Right . unpack) acct2M
+      maybeNonNull = maybe Nothing (\t -> if Data.Text.null t then Nothing else Just t)
+      acct1E = maybe (Left "to account required") (Right . unpack) $ maybeNonNull acct1M
+      acct2E = maybe (Left "from account required") (Right . unpack) $ maybeNonNull acct2M
       amt1E = maybe (Left "amount required") (either (const $ Left "could not parse amount") Right . parseWithCtx nullctx someamount . unpack) amt1M
       amt2E = maybe (Right missingamt)       (either (const $ Left "could not parse amount") Right . parseWithCtx nullctx someamount . unpack) amt2M
       journalE = maybe (Right $ journalFilePath j)
@@ -509,21 +519,20 @@ handleAdd = do
                  $forall e<-errs
                   #{e}<br>
                |]
-    redirectParams RedirectTemporary RegisterR [("add","1")]
-
    Right t -> do
     let t' = txnTieKnot t -- XXX move into balanceTransaction
     liftIO $ do ensureJournalFile journalpath
                 appendToJournalFileOrStdout journalpath $ showTransaction t'
     -- setMessage $ toHtml $ (printf "Added transaction:\n%s" (show t') :: String)
     setMessage [$shamlet|<span>Added transaction:<small><pre>#{chomp $ show t'}</pre></small>|]
-    redirectParams RedirectTemporary RegisterR [("add","1")]
+
+  redirect (RegisterR, [("add","1")])
 
 chomp :: String -> String
 chomp = reverse . dropWhile (`elem` "\r\n") . reverse
 
 -- | Handle a post from the journal edit form.
-handleEdit :: Handler RepPlain
+handleEdit :: Handler RepHtml
 handleEdit = do
   VD{..} <- getViewData
   -- get form input values, or validation errors.
@@ -544,7 +553,7 @@ handleEdit = do
   if not $ null errs
    then do
     setMessage $ toHtml (intercalate "; " errs :: String)
-    redirect RedirectTemporary JournalR
+    redirect JournalR
 
    else do
     -- try to avoid unnecessary backups or saving invalid data
@@ -555,24 +564,24 @@ handleEdit = do
     if not changed
      then do
        setMessage "No change"
-       redirect RedirectTemporary JournalR
+       redirect JournalR
      else do
       jE <- liftIO $ journalFromPathAndString Nothing journalpath tnew
       either
        (\e -> do
           setMessage $ toHtml e
-          redirect RedirectTemporary JournalR)
+          redirect JournalR)
        (const $ do
           liftIO $ writeFileWithBackup journalpath tnew
           setMessage $ toHtml (printf "Saved journal %s\n" (show journalpath) :: String)
-          redirect RedirectTemporary JournalR)
+          redirect JournalR)
        jE
 
 -- | Handle a post from the journal import form.
-handleImport :: Handler RepPlain
+handleImport :: Handler RepHtml
 handleImport = do
   setMessage "can't handle file upload yet"
-  redirect RedirectTemporary JournalR
+  redirect JournalR
   -- -- get form input values, or basic validation errors. E means an Either value.
   -- fileM <- runFormPost $ maybeFileInput "file"
   -- let fileE = maybe (Left "No file provided") Right fileM
@@ -580,11 +589,11 @@ handleImport = do
   -- case fileE of
   --  Left errs -> do
   --   setMessage errs
-  --   redirect RedirectTemporary JournalR
+  --   redirect JournalR
 
   --  Right s -> do
   --    setMessage s
-  --    redirect RedirectTemporary JournalR
+  --    redirect JournalR
 
 ----------------------------------------------------------------------
 -- | Other view components.
@@ -675,7 +684,7 @@ searchform VD{..} = [$hamlet|
 addform :: ViewData -> HtmlUrl AppRoute
 addform vd@VD{..} = [$hamlet|
 <script type=text/javascript>
- $(document).ready(function() {
+ \$(document).ready(function() {
     /* dhtmlxcombo setup */
     window.dhx_globalImgPath="../static/";
     var desccombo  = new dhtmlXCombo("description");
